﻿using DigiKidsStandAlone.Models.ViewModels;
using Microsoft.AspNetCore.Authorization;
using Microsoft.AspNetCore.Identity;
using Microsoft.AspNetCore.Mvc;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Threading.Tasks;
using DigiKidsStandAlone.Models;
using Microsoft.AspNetCore.Mvc.Rendering;

namespace DigiKidsStandAlone.Controllers
{
    public class AccountController : Controller
    {
        private UserManager<IdentityUser> userManager;
        private SignInManager<IdentityUser> signInManager;
        private RoleManager<IdentityRole> roleManager;
        private IDigiKidsRepository repository;

        public AccountController(UserManager<IdentityUser> usrMgr, SignInManager<IdentityUser> signInMgr, RoleManager<IdentityRole>  roleMgr, IDigiKidsRepository repo)
        {
            userManager = usrMgr;
            signInManager = signInMgr;
            roleManager = roleMgr;
            repository = repo;
        }

        [HttpGet]
        public ViewResult Login(string returnUrl)
        {
            return View(new LoginViewModel
            {
                ReturnUrl = returnUrl
            });
        }

        [HttpPost]
        public async Task<IActionResult> Login(LoginViewModel login)
        {
            if (ModelState.IsValid)
            {
                IdentityUser user = await userManager.FindByNameAsync(login.UserName);
                if (user != null)
                {
                    await signInManager.SignOutAsync(); // best practice eerst afmelden ondat het een open sessie zou kunne hebbe
                    if ((await signInManager.PasswordSignInAsync(login.UserName, login.Password, false, false)).Succeeded)
                    {
                        IList<string> role = await userManager.GetRolesAsync(user);

                        if(role.FirstOrDefault() == "Administrators")
                        {
                            login.ReturnUrl = "/admin/index";
                        }
                        else if(role.FirstOrDefault() == "Teachers")
                        {
                            login.ReturnUrl = "/teacher/index";
                        }
                        else if(role.FirstOrDefault() == "Parents")
                        {
                            login.ReturnUrl = "/home/index";

                        }

                        return Redirect(login.ReturnUrl);
                    }
                }
            }

            ModelState.AddModelError("", "Invalid name or password");

            return View(login);
        }

        public ViewResult Register()
        {
            var zips = repository.ZipCodes;
                
            RegisterViewModel register = new RegisterViewModel { ZipCodes = new SelectList(zips, "Id", "Zip") };
            return View(register);
        }

        [HttpPost]
        public async Task<IActionResult> Register(RegisterViewModel register)
        {
            var zips = repository.ZipCodes;
            register.ZipCodes = new SelectList(zips, "Id", "Zip");

            if (ModelState.IsValid)
            {
                bool validUserName = false;
                bool validEmail = false;
                bool validPassword = false;
                IdentityUser newUser = await userManager.FindByNameAsync(register.UserName);

                if(newUser == null) validUserName = true;
                if(register.Email1 == register.Email2) validEmail = true;
                if(register.Password1 == register.Password2) validPassword = true;

                if (validUserName && validEmail && validPassword)
                {
                    newUser = new IdentityUser(register.UserName);
                    newUser.Email = register.Email1;
                    newUser.PhoneNumber = register.Telephone;
                    newUser.LockoutEnabled = true;

                    await userManager.CreateAsync(newUser, register.Password1);
                    IdentityUser checkUser = await userManager.FindByNameAsync(register.UserName);
                    if(checkUser != null)
                    {
                        Parent parent = new Parent
                        {
                            UserName = register.UserName,
                            Name = register.Name,
                            FirstName = register.FirstName,
                            Zip = zips.FirstOrDefault(x=>x.Id == register.Zip),
                            Address = register.Address,
                            Telephone = register.Telephone,
                            Email = register.Email1
                        };

                        repository.CreateParent(parent);
                        return Redirect("/");
                    }
                }
            }

            return View(register);
        }

        [Authorize]
        public async Task<RedirectResult> Logout()  // redirect
        {
            await signInManager.SignOutAsync();
            return Redirect("/");
        }
    }
}