﻿using DigiKidsStandAlone.Models;
using DigiKidsStandAlone.Models.ViewModels;
using Microsoft.AspNetCore.Authorization;
using Microsoft.AspNetCore.Identity;
using Microsoft.AspNetCore.Mvc;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Threading.Tasks;

namespace DigiKidsStandAlone.Controllers
{
    public class HomeController : Controller
    {
        private UserManager<IdentityUser> userManager;
        private IDigiKidsRepository repository;
        private Parent currentParent;

        public HomeController(UserManager<IdentityUser> usrMgr, IDigiKidsRepository repo)
        {
            userManager = usrMgr;
            repository = repo;
        }

        [Authorize(Roles = "Parents")]
        public async Task<ViewResult> Index()
        {
            await GetBasicData();
            return View();
        }

        public async Task<ViewResult> UserSettings()
        {
            await GetBasicData();
            return View(currentParent);
        }

        [HttpGet]
        public async Task<ViewResult> AddChild()
        {
            await GetBasicData();
            AddChildViewModel addChildViewModel = new AddChildViewModel
            {
                ClassRooms = repository.ClassRooms,
                Child = new Child()
            };
            addChildViewModel.Child.Parent = currentParent;

            return View(addChildViewModel);
        }

        [HttpPost]
        public async Task<ActionResult> AddChild(Child child)
        {
            await GetBasicData();
            currentParent.Children.Add(child);
            repository.SaveParent(currentParent);
            return Redirect("/Home");
            
        }

        private async Task GetBasicData()
        {
            //Check who is logged in and get parent object
            IdentityUser currentLogin = await userManager.GetUserAsync(HttpContext.User);
            currentParent = repository.Parents.Where(x => x.UserName == currentLogin.UserName).FirstOrDefault();
            ViewBag.FirstName = currentParent.FirstName;
        }
    }
}
