﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Threading.Tasks;
using Microsoft.EntityFrameworkCore;

namespace DigiKidsStandAlone.Models
{
    public class EFDigiKidsRepository : IDigiKidsRepository
    {
        private DigiKidsDbContext context;

        public EFDigiKidsRepository(DigiKidsDbContext ctx)
        {
            context = ctx;
        }

        public IQueryable<ZipCode> ZipCodes => context.ZipCodes;
        public IQueryable<Child> Children => context.Children.Include(c => c.Parent).Include(c=>c.ClassRoom);
        public IQueryable<ClassRoom> ClassRooms => context.ClassRooms;
        public IQueryable<Parent> Parents => context.Parents.Include(c => c.Children).ThenInclude(c=> c.ClassRoom).Include(c => c.Zip);
        public IQueryable<Teacher> Teachers => context.Teachers.Include(c=>c.Zip).Include(c => c.ClassRooms).ThenInclude(c => c.Children);
        public IQueryable<DayCare> DayCares => context.DayCares.Include(c => c.Parent).Include(c => c.Type);
        public IQueryable<DayCareType> DayCareTypes => context.DayCareTypes;
        
        public async void CreateParent(Parent parent)
        {
            context.Parents.Add(parent);
            await context.SaveChangesAsync();
        }

        public async void SaveParent(Parent parent)
        {
            await context.SaveChangesAsync();
        }
    }
}
