﻿using Microsoft.AspNetCore.Builder;
using Microsoft.AspNetCore.Identity;
using Microsoft.Extensions.DependencyInjection;
using Microsoft.EntityFrameworkCore;
using System.Linq;
using DigiKidsStandAlone.Models;

namespace DigiKidsStandAlone.Models{

    public static class IdentitySeedData {
        private const string adminUser = "Admin";
        private const string teacherUser = "Teacher";
        private const string parentUser = "Parent";
        private const string dtcUser = "Dtc";

        private const string password = "Secret123$";


        private const string admingRole = "Administrators";
        private const string teacherRole = "Teachers";
        private const string parentRole = "Parents";
        private const string directorRole = "Directors";

        public static async void EnsurePopulated(IApplicationBuilder app) {

            AppIdentityDbContext context = app.ApplicationServices
                .CreateScope().ServiceProvider
                .GetRequiredService<AppIdentityDbContext>();
            if (context.Database.GetPendingMigrations().Any()) {
                context.Database.Migrate();
            }

            RoleManager<IdentityRole> roleManager = app.ApplicationServices.CreateScope().ServiceProvider.GetRequiredService<RoleManager<IdentityRole>>();
            UserManager<IdentityUser> userManager = app.ApplicationServices.CreateScope().ServiceProvider.GetRequiredService<UserManager<IdentityUser>>();

            IdentityRole role1 = await roleManager.FindByIdAsync(admingRole);
            if (role1 == null)
            {
                role1 = new IdentityRole(admingRole);
                await roleManager.CreateAsync(role1);
            }

            IdentityRole role2 = await roleManager.FindByIdAsync(teacherRole);
            if (role2 == null)
            {
                role2 = new IdentityRole(teacherRole);
                await roleManager.CreateAsync(role2);
            }

            IdentityRole role3 = await roleManager.FindByIdAsync(parentRole);
            if (role3 == null)
            {
                role3 = new IdentityRole(parentRole);
                await roleManager.CreateAsync(role3);
            }

            IdentityRole role4 = await roleManager.FindByIdAsync(directorRole);
            if (role4 == null)
            {
                role4 = new IdentityRole(directorRole);
                await roleManager.CreateAsync(role4);
            }

            IdentityUser user1 = await userManager.FindByIdAsync(adminUser);
            if (user1 == null)
            {
                user1 = new IdentityUser(adminUser);
                user1.Email = "admin@example.com";
                user1.PhoneNumber = "555-1234";
                await userManager.CreateAsync(user1, password);
                await userManager.AddToRoleAsync(user1, admingRole);
            }

            IdentityUser user2 = await userManager.FindByIdAsync(teacherUser);
            if (user2 == null)
            {
                user2 = new IdentityUser(teacherUser);
                user2.Email = "teacher@example.com";
                user2.PhoneNumber = "555-1235";
                await userManager.CreateAsync(user2, password);
                await userManager.AddToRoleAsync(user2, teacherRole);
            }

            IdentityUser user3 = await userManager.FindByIdAsync(parentUser);
            if (user3 == null)
            {
                user3 = new IdentityUser(parentUser);
                user3.Email = "parent@example.com";
                user3.PhoneNumber = "7555-1235";
                await userManager.CreateAsync(user3, password);
                await userManager.AddToRoleAsync(user3, parentRole);
            }

            //IdentityUser user4 = await userManager.FindByIdAsync(parentUser);
            //if (user4 == null)
            //{
            //    user4 = new IdentityUser(dtcUser);
            //    user4.Email = "parent@example.com";
            //    user4.PhoneNumber = "7555-1235";
            //    IdentityResult checkuser =  await userManager.CreateAsync(user4, password);
            //    if (checkuser.Succeeded)
            //    {
            //        await userManager.AddToRoleAsync(user4, parentRole);
            //    }
            //}
        }
    }
}