﻿using System.Linq;
using Microsoft.AspNetCore.Builder;
using Microsoft.Extensions.DependencyInjection;
using Microsoft.EntityFrameworkCore;
using System.Collections.Generic;
using System;

namespace DigiKidsStandAlone.Models
{
    public static class SeedData
    {
        public static void EnsurePopulated(IApplicationBuilder app)
        {
            DigiKidsDbContext context = app.ApplicationServices
                .CreateScope().ServiceProvider.GetRequiredService<DigiKidsDbContext>();

            if (context.Database.GetPendingMigrations().Any())
            {
                context.Database.Migrate();
            }


            // Zipcodes //
            ZipCode zipHouthalen = null;
            ZipCode zipGenk = null;

            if (!context.ZipCodes.Any())
            {
                context.ZipCodes.AddRange(
                   zipHouthalen = new ZipCode
                   {
                       Zip = 3530,
                       City = "Houthalen"
                   },
                    new ZipCode
                    {
                        Zip = 3560,
                        City = "Lummen"
                    },
                    new ZipCode
                    {
                        Zip = 3590,
                        City = "Diepenbeek"
                    },
                    zipGenk= new ZipCode
                    {
                        Zip = 3600,
                        City = "Genk"
                    },
                    new ZipCode
                    {
                        Zip = 3500,
                        City = "Hasselt"
                    });

                context.SaveChanges();
            }


            // Teachers && ClassRooms//
            Teacher tFransJ = null;
            Teacher tJaneV = null;
            ClassRoom onea = null;
            ClassRoom twoa = null;
            ClassRoom treea = null;

            if (!context.Teachers.Any())
            {
                context.Teachers.AddRange(
                    tFransJ = new Teacher
                    {
                        FirstName = "Frans",
                        Name = "Jansens",
                        Address = "Berkelaan 5",
                        Zip = zipGenk,
                        Telephone = "0479967412",
                        Email = "FransJ@hotmail.com",
                        ClassRooms = new List<ClassRoom>{
                            (onea = new ClassRoom{
                                ClassName = "1A",
                                Teacher = tFransJ
                            }),
                            (twoa = new ClassRoom{
                                ClassName = "2A",
                                Teacher = tFransJ
                            })
                        },
                        UserName = "Teacher"
                    },
                    tJaneV = new Teacher
                    {
                        FirstName = "Jane",
                        Name = "Vermeiren",
                        Address = "Lotusbloemstraat 64",
                        Zip = zipHouthalen,
                        Telephone = "0497452174",
                        Email = "JaneV@skynet.be",
                        ClassRooms = new List<ClassRoom>{
                           (treea = new ClassRoom{
                                ClassName = "3A",
                                Teacher = tJaneV
                           })                        
                        },
                        UserName = "Teacher"
                    });

                context.SaveChanges();
            }


            // Parents //
            Parent pStevenK = null;
            Parent pNatasjaS = null;

            if (!context.Parents.Any())
            {
                context.Parents.AddRange(
                    pStevenK = new Parent
                    {
                        FirstName = "Steven",
                        Name = "Kazmierczak",
                        Address = "Koekoeksstraat 5",
                        Zip = zipHouthalen,
                        Telephone = "0477985612",
                        Email = "stevenk@telenet.be",
                        UserName = "Parent"
                    },
                    pNatasjaS = new Parent
                    {
                        FirstName = "Natasja",
                        Name = "Stravedis",
                        Address = "Herenbaan Oost 2a",
                        Zip = zipHouthalen,
                        Telephone = "0495321478",
                        Email = "natasjas@gmail.com",
                        Children = new List<Child>
                        {
                            new Child
                            {
                                FirstName = "Laura",
                                Name = "Kunst",
                                Parent = pNatasjaS,
                                ClassRoom = twoa,
                                Confirmed = false
                            },
                            new Child
                            {
                                FirstName = "Sven",
                                Name = "Kunst",
                                Parent = pNatasjaS,
                                ClassRoom = treea,
                                Confirmed = false
                            }
                        },
                        UserName = "Parent"
                    });;

                context.SaveChanges();
            }



            //DayCareTypes //
            DayCareType dctBefore = null;
            DayCareType dctAfter = null;

            if (!context.DayCareTypes.Any())
            {
                context.DayCareTypes.AddRange(
                    dctBefore = new DayCareType
                    {
                        Name = "Before School"
                    },
                    dctAfter = new DayCareType
                    {
                        Name = "After School"
                    }
                );

                context.SaveChanges();
            }



            // DayCares
            //if (!context.DayCares.Any())
            //{
            //    context.DayCares.AddRange(
            //        new DayCare
            //        {
            //            Child = pNatasjaS.Children.FirstOrDefault(),
            //            Parent = pNatasjaS,
            //            Type = dctAfter,
            //            Time = new DateTime()
            //        }
            //    );

            //    context.SaveChanges();
            //}
        }
    }
}
