using DigiKidsStandAlone.Models;
using Microsoft.AspNetCore.Builder;
using Microsoft.AspNetCore.Hosting;
using Microsoft.AspNetCore.Http;
using Microsoft.AspNetCore.Identity;
using Microsoft.EntityFrameworkCore;
using Microsoft.Extensions.Configuration;
using Microsoft.Extensions.DependencyInjection;
using Microsoft.Extensions.Hosting;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Threading.Tasks;

namespace DigiKidsStandAlone
{
    public class Startup
    {
        private IConfiguration Configuration { get; set; }

        public Startup(IConfiguration config)
        {
            Configuration = config;
        }

        // This method gets called by the runtime. Use this method to add services to the container.
        // For more information on how to configure your application, visit https://go.microsoft.com/fwlink/?LinkID=398940
        public void ConfigureServices(IServiceCollection services)
        {
            services.AddControllersWithViews();
            services.AddRazorPages();               //razor
            services.AddServerSideBlazor();         //blazor
            //services.AddDistributedMemoryCache();
            //services.AddSession();


            services.AddDbContext<DigiKidsDbContext>(opts => opts.UseSqlServer(Configuration["ConnectionStrings:DigiKidsConnection"]));
            services.AddScoped<IDigiKidsRepository, EFDigiKidsRepository>();

            IServiceCollection serviceCollections = services.AddDbContext<AppIdentityDbContext>(opts => opts.UseSqlServer(Configuration["ConnectionStrings:DigiKidsIdentityConnection"]));

            services.AddIdentity<IdentityUser, IdentityRole>().AddRoles<IdentityRole>().AddEntityFrameworkStores<AppIdentityDbContext>();
        }

        // This method gets called by the runtime. Use this method to configure the HTTP request pipeline.
        public void Configure(IApplicationBuilder app, IWebHostEnvironment env)
        {
            if (env.IsDevelopment())
            {
                app.UseDeveloperExceptionPage();
            }

            app.UseStatusCodePages();
            app.UseStaticFiles();
            //app.UseSession();
            app.UseRouting();

            app.UseAuthentication();
            app.UseAuthorization();

            app.UseEndpoints(endpoints =>
            {
                endpoints.MapControllerRoute("", "",
                    new { Controller = "Account", Action = "Login" });

                endpoints.MapDefaultControllerRoute();

                //endpoints.MapRazorPages();                  //razor
                //endpoints.MapBlazorHub();                   //blazor
                //endpoints.MapFallbackToPage("/Account/Login");
            });

            IdentitySeedData.EnsurePopulated(app);
            SeedData.EnsurePopulated(app);
        }
    }
}
